package javax.swing.text.html;

import java.awt.Color;
import javax.swing.text.View;
import javax.swing.text.ViewFactory;
import java.awt.Shape;
import javax.swing.event.DocumentEvent;
import javax.swing.text.Element;
import javax.swing.text.AttributeSet;
import javax.swing.text.LabelView;

public class InlineView extends LabelView
{
    private boolean nowrap;
    private AttributeSet attr;
    
    public InlineView(Element elem) {
        super(elem);
        this.attr = this.getStyleSheet().getViewAttributes(this);
    }
    
    @Override
    public void insertUpdate(DocumentEvent e, Shape a, ViewFactory f) {
        super.insertUpdate(e, a, f);
    }
    
    @Override
    public void removeUpdate(DocumentEvent e, Shape a, ViewFactory f) {
        super.removeUpdate(e, a, f);
    }
    
    @Override
    public void changedUpdate(DocumentEvent e, Shape a, ViewFactory f) {
        super.changedUpdate(e, a, f);
        this.attr = this.getStyleSheet().getViewAttributes(this);
        this.preferenceChanged(null, true, true);
    }
    
    @Override
    public AttributeSet getAttributes() {
        return this.attr;
    }
    
    @Override
    public int getBreakWeight(int axis, float pos, float len) {
        if (this.nowrap) {
            return 0;
        }
        return super.getBreakWeight(axis, pos, len);
    }
    
    @Override
    public View breakView(int axis, int p4, float pos, float len) {
        return super.breakView(axis, p4, pos, len);
    }
    
    @Override
    protected void setPropertiesFromAttributes() {
        super.setPropertiesFromAttributes();
        AttributeSet attributes = this.getAttributes();
        Object attribute = attributes.getAttribute(CSS.Attribute.TEXT_DECORATION);
        this.setUnderline(attribute != null && attribute.toString().indexOf("underline") >= 0);
        this.setStrikeThrough(attribute != null && attribute.toString().indexOf("line-through") >= 0);
        Object attribute2 = attributes.getAttribute(CSS.Attribute.VERTICAL_ALIGN);
        this.setSuperscript(attribute2 != null && attribute2.toString().indexOf("sup") >= 0);
        this.setSubscript(attribute2 != null && attribute2.toString().indexOf("sub") >= 0);
        Object attribute3 = attributes.getAttribute(CSS.Attribute.WHITE_SPACE);
        if (attribute3 != null && attribute3.equals("nowrap")) {
            this.nowrap = true;
        }
        else {
            this.nowrap = false;
        }
        Color background = ((HTMLDocument)this.getDocument()).getBackground(attributes);
        if (background != null) {
            this.setBackground(background);
        }
    }
    
    protected StyleSheet getStyleSheet() {
        return ((HTMLDocument)this.getDocument()).getStyleSheet();
    }
}
